@@ -6,8 +6,8 @@ use warnings;
 sub set {
     my $pkg = shift;
 
-    require Log::ger;
-    Log::ger::set_output(@_);
+    require Log::ger::Util;
+    Log::ger::Util::set_output(@_);
 }
 
 sub import {
@@ -32,7 +32,7 @@ Log::ger::Output - Set logging output
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -48,6 +48,10 @@ or:
 
 =for Pod::Coverage ^(.+)$
 
+=head1 SEE ALSO
+
+Modelled after L<Log::Any::Adapter>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
